@@ -1,14 +1,14 @@
 """
 Type annotations for codeartifact service literal definitions.
 
-[Open documentation](./literals.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/literals.html)
 
 Usage::
 
     ```python
-    from mypy_boto3_codeartifact.literals import DomainStatus
+    from mypy_boto3_codeartifact.literals import DomainStatusType
 
-    data: DomainStatus = "Active"
+    data: DomainStatusType = "Active"
     ```
 """
 import sys
@@ -20,33 +20,33 @@ else:
 
 
 __all__ = (
-    "DomainStatus",
-    "ExternalConnectionStatus",
-    "HashAlgorithm",
+    "DomainStatusType",
+    "ExternalConnectionStatusType",
+    "HashAlgorithmType",
     "ListDomainsPaginatorName",
     "ListPackageVersionAssetsPaginatorName",
     "ListPackageVersionsPaginatorName",
     "ListPackagesPaginatorName",
     "ListRepositoriesInDomainPaginatorName",
     "ListRepositoriesPaginatorName",
-    "PackageFormat",
-    "PackageVersionErrorCode",
-    "PackageVersionSortType",
-    "PackageVersionStatus",
+    "PackageFormatType",
+    "PackageVersionErrorCodeType",
+    "PackageVersionSortTypeType",
+    "PackageVersionStatusType",
 )
 
 
-DomainStatus = Literal["Active", "Deleted"]
-ExternalConnectionStatus = Literal["Available"]
-HashAlgorithm = Literal["MD5", "SHA-1", "SHA-256", "SHA-512"]
+DomainStatusType = Literal["Active", "Deleted"]
+ExternalConnectionStatusType = Literal["Available"]
+HashAlgorithmType = Literal["MD5", "SHA-1", "SHA-256", "SHA-512"]
 ListDomainsPaginatorName = Literal["list_domains"]
 ListPackageVersionAssetsPaginatorName = Literal["list_package_version_assets"]
 ListPackageVersionsPaginatorName = Literal["list_package_versions"]
 ListPackagesPaginatorName = Literal["list_packages"]
 ListRepositoriesInDomainPaginatorName = Literal["list_repositories_in_domain"]
 ListRepositoriesPaginatorName = Literal["list_repositories"]
-PackageFormat = Literal["maven", "npm", "nuget", "pypi"]
-PackageVersionErrorCode = Literal[
+PackageFormatType = Literal["maven", "npm", "nuget", "pypi"]
+PackageVersionErrorCodeType = Literal[
     "ALREADY_EXISTS",
     "MISMATCHED_REVISION",
     "MISMATCHED_STATUS",
@@ -54,7 +54,7 @@ PackageVersionErrorCode = Literal[
     "NOT_FOUND",
     "SKIPPED",
 ]
-PackageVersionSortType = Literal["PUBLISHED_TIME"]
-PackageVersionStatus = Literal[
+PackageVersionSortTypeType = Literal["PUBLISHED_TIME"]
+PackageVersionStatusType = Literal[
     "Archived", "Deleted", "Disposed", "Published", "Unfinished", "Unlisted"
 ]
